aboutsummaryrefslogtreecommitdiff
path: root/lib/csapi/definitions/wellknown/homeserver.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/csapi/definitions/wellknown/homeserver.h')
-rw-r--r--lib/csapi/definitions/wellknown/homeserver.h30
1 files changed, 16 insertions, 14 deletions
diff --git a/lib/csapi/definitions/wellknown/homeserver.h b/lib/csapi/definitions/wellknown/homeserver.h
index f6761c30..606df88b 100644
--- a/lib/csapi/definitions/wellknown/homeserver.h
+++ b/lib/csapi/definitions/wellknown/homeserver.h
@@ -6,21 +6,23 @@
#include "converters.h"
+namespace Quotient
+{
+
+// Data structures
-namespace QMatrixClient
+/// Used by clients to discover homeserver information.
+struct HomeserverInformation
{
- // Data structures
+ /// The base URL for the homeserver for client-server connections.
+ QString baseUrl;
+};
- /// Used by clients to discover homeserver information.
- struct HomeserverInformation
- {
- /// The base URL for the homeserver for client-server connections.
- QString baseUrl;
- };
- template <> struct JsonObjectConverter<HomeserverInformation>
- {
- static void dumpTo(QJsonObject& jo, const HomeserverInformation& pod);
- static void fillFrom(const QJsonObject& jo, HomeserverInformation& pod);
- };
+template <>
+struct JsonObjectConverter<HomeserverInformation>
+{
+ static void dumpTo(QJsonObject& jo, const HomeserverInformation& pod);
+ static void fillFrom(const QJsonObject& jo, HomeserverInformation& pod);
+};
-} // namespace QMatrixClient
+} // namespace Quotient